OC.L10N.register(
    "settings",
    {
    "Email sent" : "ईमेल भेज दिया गया है ",
    "Cancel" : "रद्द करें ",
    "Password" : "पासवर्ड",
    "New password" : "नया पासवर्ड",
    "Username" : "प्रयोक्ता का नाम",
    "Personal" : "यक्तिगत",
    "Error" : "त्रुटि",
    "Delete" : "हटाना",
    "Share" : "साझा करें",
    "Add" : "डाले"
},
"nplurals=2; plural=(n != 1);");
